# Further Reading

This section provides curated resources and best practices for Python development, Git/GitHub workflows, project maintenance, and general software engineering. Use these references to deepen your knowledge and keep your projects robust and maintainable.

## Python, Packaging, and Project Structure

- [The Hitchhiker’s Guide to Python](https://docs.python-guide.org/)
- [Python Packaging User Guide](https://packaging.python.org/)
- [PEP 8 – Style Guide for Python Code](https://peps.python.org/pep-0008/)
- [PEP 517/518 – Modern Python packaging standards](https://peps.python.org/pep-0517/)
- [Google Python Style Guide](https://google.github.io/styleguide/pyguide.html)
- [Git Large File Storage (LFS)](https://git-lfs.github.com/)

## Git and GitHub Best Practices

- [Pro Git Book](https://git-scm.com/book/en/v2)
- [GitHub Docs: Best Practices](https://docs.github.com/en/get-started/quickstart/github-flow)
- [GitHub Actions Documentation](https://docs.github.com/en/actions)
- [Branch Protection Rules](https://docs.github.com/en/repositories/configuring-branches-and-merges-in-your-repository/managing-protected-branches/managing-a-branch-protection-rule)
- [Configuring Issue Templates](https://docs.github.com/en/communities/using-templates-to-encourage-useful-issues-and-pull-requests/configuring-issue-templates-for-your-repository#configuring-the-template-chooser)
- [Conventional Commits](https://www.conventionalcommits.org/en/v1.0.0/)

## Security and Maintenance

- [Dependabot Documentation](https://docs.github.com/en/code-security/dependabot)
- [CodeQL Documentation](https://codeql.github.com/docs/codeql-overview/about-codeql/)
- [NEP 29 – Python version support policy](https://numpy.org/neps/nep-0029-deprecation_policy.html)
- [Python Developer's Guide: Supported Versions](https://devguide.python.org/versions/#status-of-python-versions)
